﻿$MaxMoment = 25000
$LineLoad = -1000
$Increment = -2000

# Determine the path where the script is run
$ScriptPath = Split-Path -parent $MyInvocation.MyCommand.Definition

$SENpath = "d:\SCIA\Builds\R18_0\"
$Projectfile = "$ScriptPath\Beam.esa"
$InputXMLfile = "$ScriptPath\Beam.xml"
$OutputXMLfile = "$ScriptPath\Beam_Out.xml"
$OutputdefXMLfile = "$ScriptPath\Beam_Out.xml.def"


$xml = [xml](Get-Content $InputXMLfile)
$Iterator = 1

# $LineLoadArray = @()
# $MomentArray = @()

DO
{
    # Change lineload value and store in temporary XML
    $xml.project.container.table.obj.p6.v = $LineLoad.ToString()
    $TempXMLFile = "$ScriptPath\Beam_temp.xml"
    $xml.Save($TempXMLFile)


    # Run esa_xml.exe and export the XML doc called RESULTS
    cmd.exe /c "$SENpath\esa_xml.exe LIN $Projectfile $TempXMLFile /x$OutputXMLfile /mRESULTS"

    # Wait for results file to appear
    while (!(Test-Path $OutputXMLfile)) { Start-Sleep 10 }

    # Read resulting moment value after calculation
    $Outxml = [xml](Get-Content $OutputXMLfile)
    [double]$Moment = $Outxml.project.container.table.obj.p0.row[2].p9.v

    # Cleanup temporary files
    Remove-Item $TempXMLFile
    Remove-Item $OutputXMLfile
    Remove-Item $OutputdefXMLfile # gets generated by SEN

    # Print the Output data
    'Iteration {0}: Lineload q = {1} gives a moment of {2}' -f $Iterator, $LineLoad, $Moment

    # $LineLoadArray += $LineLoad
    # $MomentArray += $Moment

    # Increment load
    $LineLoad += $Increment
    $Iterator++

} While ($Moment -lt $MaxMoment)


# Making table for CSV Export
<#
$Table = For ($i = 0; $i -lt $LineLoadArray.Count; $i++) {
    New-Object -TypeName psobject -Property @{
        'Lineload' = $(If ($LineLoadArray[$i]) { $LineLoadArray[$i] })
        'Moment' = $(If ($MomentArray[$i]) { $MomentArray[$i] })
    }
}
#>

# CSV export
# $Table | Select-Object -Property Lineload, Moment | Export-Csv Out.csv -NoTypeInformation -Delimiter ";"